maite.protocols.image\_classification.Augmentation
==================================================

.. currentmodule:: maite.protocols.image_classification

.. autoclass:: Augmentation

   
   
   